# Contributing

---
When contributing to this repository, please first discuss the change you wish to make via [issue](https://github.com/AI2Business/mkdocstrings-sourcelink/issues) or any other method with this repository owners before making a change.

Please note we have a code of conduct. Please follow it in all your interactions with the project.

## Pull Request Process

---

1. Ensure any install or build dependencies are removed before the end of the layer when doing a build.
2. Ensure you are follwing the code style.
3. Update the `docstrings` and the [README.md](https://github.com/AI2Business/mkdocstrings-sourcelink/blob/main/README.md).
